DOCUMENTATION for general Tellor Protocol client software (telliot) setup, creating new datafeeds, adding spot prices, reporting values to oracles, and more has moved [HERE](https://tellor-io.github.io/telliot-feeds/).
